[U-Boot] [PATCH 3/5] dm: ofnode: rename ofnode_read_prop() to ofnode_get_property()

Masahiro Yamada yamada.masahiro at socionext.com
Thu Jun 22 07:54:05 UTC 2017


This function returns the pointer to the value of a node property.
The current name ofnode_read_prop() is confusing.  Follow the naming
of_get_property() from Linux.

The return type (const u32 *) is wrong.  DT property values can be
strings as well as integers.  This is why of_get_property/fdt_getprop
returns an opaque pointer.

Signed-off-by: Masahiro Yamada <yamada.masahiro at socionext.com>
---

 drivers/core/lists.c             | 3 +--
 drivers/core/ofnode.c            | 4 ++--
 drivers/core/read.c              | 2 +-
 drivers/misc/cros_ec_sandbox.c   | 2 +-
 drivers/pci/pci-uclass.c         | 2 +-
 drivers/pinctrl/pinctrl-uclass.c | 2 +-
 include/dm/ofnode.h              | 4 ++--
 include/dm/read.h                | 2 +-
 8 files changed, 10 insertions(+), 11 deletions(-)

diff --git a/drivers/core/lists.c b/drivers/core/lists.c
index b79f26dbe6c9..6067914e8117 100644
--- a/drivers/core/lists.c
+++ b/drivers/core/lists.c
@@ -141,8 +141,7 @@ int lists_bind_fdt(struct udevice *parent, ofnode node, struct udevice **devp)
 	name = ofnode_get_name(node);
 	dm_dbg("bind node %s\n", name);
 
-	compat_list = (const char *)ofnode_read_prop(node, "compatible",
-						     &compat_length);
+	compat_list = ofnode_get_property(node, "compatible", &compat_length);
 	if (!compat_list) {
 		if (compat_length == -FDT_ERR_NOTFOUND) {
 			dm_dbg("Device '%s' has no compatible string\n", name);
diff --git a/drivers/core/ofnode.c b/drivers/core/ofnode.c
index 08b3e03b1e8e..87e731dc2b77 100644
--- a/drivers/core/ofnode.c
+++ b/drivers/core/ofnode.c
@@ -422,7 +422,7 @@ int ofnode_decode_display_timing(ofnode parent, int index,
 	return ret;
 }
 
-const u32 *ofnode_read_prop(ofnode node, const char *propname, int *lenp)
+const void *ofnode_get_property(ofnode node, const char *propname, int *lenp)
 {
 	if (ofnode_is_np(node))
 		return of_get_property(ofnode_to_np(node), propname, lenp);
@@ -493,7 +493,7 @@ int ofnode_read_pci_addr(ofnode node, enum fdt_pci_space type,
 	 * #size-cells. They need to be 3 and 2 accordingly. However,
 	 * for simplicity we skip the check here.
 	 */
-	cell = ofnode_read_prop(node, propname, &len);
+	cell = ofnode_get_property(node, propname, &len);
 	if (!cell)
 		goto fail;
 
diff --git a/drivers/core/read.c b/drivers/core/read.c
index 3131e5379c96..c1fe949808fa 100644
--- a/drivers/core/read.c
+++ b/drivers/core/read.c
@@ -106,7 +106,7 @@ int dev_read_phandle(struct udevice *dev)
 
 const u32 *dev_read_prop(struct udevice *dev, const char *propname, int *lenp)
 {
-	return ofnode_read_prop(dev_ofnode(dev), propname, lenp);
+	return ofnode_get_property(dev_ofnode(dev), propname, lenp);
 }
 
 int dev_read_alias_seq(struct udevice *dev, int *devnump)
diff --git a/drivers/misc/cros_ec_sandbox.c b/drivers/misc/cros_ec_sandbox.c
index c96e26e6b782..5924adee4085 100644
--- a/drivers/misc/cros_ec_sandbox.c
+++ b/drivers/misc/cros_ec_sandbox.c
@@ -197,7 +197,7 @@ static int keyscan_read_fdt_matrix(struct ec_state *ec, ofnode node)
 	int upto;
 	int len;
 
-	cell = ofnode_read_prop(node, "linux,keymap", &len);
+	cell = ofnode_get_property(node, "linux,keymap", &len);
 	ec->matrix_count = len / 4;
 	ec->matrix = calloc(ec->matrix_count, sizeof(*ec->matrix));
 	if (!ec->matrix) {
diff --git a/drivers/pci/pci-uclass.c b/drivers/pci/pci-uclass.c
index b36ef3338ceb..922401f2a015 100644
--- a/drivers/pci/pci-uclass.c
+++ b/drivers/pci/pci-uclass.c
@@ -763,7 +763,7 @@ static int decode_regions(struct pci_controller *hose, ofnode parent_node,
 	int len;
 	int i;
 
-	prop = ofnode_read_prop(node, "ranges", &len);
+	prop = ofnode_get_property(node, "ranges", &len);
 	if (!prop)
 		return -EINVAL;
 	pci_addr_cells = ofnode_read_addr_cells(node);
diff --git a/drivers/pinctrl/pinctrl-uclass.c b/drivers/pinctrl/pinctrl-uclass.c
index 02e269020df5..114952a1da36 100644
--- a/drivers/pinctrl/pinctrl-uclass.c
+++ b/drivers/pinctrl/pinctrl-uclass.c
@@ -134,7 +134,7 @@ static int pinconfig_post_bind(struct udevice *dev)
 		 * If this node has "compatible" property, this is not
 		 * a pin configuration node, but a normal device. skip.
 		 */
-		ofnode_read_prop(node, "compatible", &ret);
+		ofnode_get_property(node, "compatible", &ret);
 		if (ret >= 0)
 			continue;
 
diff --git a/include/dm/read.h b/include/dm/read.h
index 8c9846eaf26f..562881962a64 100644
--- a/include/dm/read.h
+++ b/include/dm/read.h
@@ -389,7 +389,7 @@ static inline int dev_read_phandle(struct udevice *dev)
 static inline const u32 *dev_read_prop(struct udevice *dev,
 				       const char *propname, int *lenp)
 {
-	return ofnode_read_prop(dev_ofnode(dev), propname, lenp);
+	return ofnode_get_property(dev_ofnode(dev), propname, lenp);
 }
 
 static inline int dev_read_alias_seq(struct udevice *dev, int *devnump)
diff --git a/include/dm/ofnode.h b/include/dm/ofnode.h
index 149622a0b2c9..1c507c9f1688 100644
--- a/include/dm/ofnode.h
+++ b/include/dm/ofnode.h
@@ -463,14 +463,14 @@ int ofnode_decode_display_timing(ofnode node, int index,
 				 struct display_timing *config);
 
 /**
  * ofnode_read_prop()- - read a node property
  *
  * @node: node to read
  * @propname: property to read
  * @lenp: place to put length on success
  * @return pointer to property, or NULL if not found
  */
-const u32 *ofnode_read_prop(ofnode node, const char *propname, int *lenp);
+const void *ofnode_get_property(ofnode node, const char *propname, int *lenp);
 
 /**
  * ofnode_is_available() - check if a node is marked available
@@ -463,14 +463,14 @@ int ofnode_decode_display_timing(ofnode node, int index,
 
 /**
- * ofnode_read_prop()- - read a node property
+ * ofnode_get_property()- - get a pointer to the value of a node property
  *
  * @node: node to read
-- 
2.7.4



More information about the U-Boot mailing list